@@ -197,13 +197,8 @@ class NotVirtualServiceInstanceError(KempTechApiException):
         super(NotVirtualServiceInstanceError, self).__init__(msg, code=code)
 
 
-class AccessControlMissingLoadmasterInfo(MissingInfo):
-    service = 'Access Control'
-    param_name = 'LoadMaster'
-
-
-class AccessControlMissingVirtualServiceInfo(MissingInfo):
-    service = 'Access Control'
+class VirtualServiceACLMissingVirtualServiceInfo(MissingInfo):
+    service = 'VirtualServiceACL'
     param_name = 'Virtual service'
 
 
@@ -251,3 +246,10 @@ class RangeMaskInvalid(ValidationError):
     def __init__(self, mask):
         msg = "Specified netmask is invalid. Mask must be between 8-32"
         super(RangeMaskInvalid, self).__init__(msg)
+
+
+class CipherListInvalid(ValidationError):
+    def __init__(self, ciphers):
+        msg = "Specified cipher list is invalid. Must be either a list or a "\
+              "string in the cipher list format"
+        super(CipherListInvalid, self).__init__(msg)
